package FriendTamagotchiAgentPackage;

import java.util.*;
import jade.core.*;
import jade.core.behaviours.*;
import jade.lang.acl.*;

import TamagotchiOntology.*;

/**
 * Class MessageHandler is waiting for incoming messages and will
 * forward the message to an appropriate behaviour
 */
class MessageHandler extends CyclicBehaviour {

    /** Placeholder for the received message */
    private ACLMessage receivedMessage;

    /** My OwnerAgent */
    private FriendTamagotchiAgent friendTamagotchiAgent;

    /** User interface */
    private UserInterface userInterface;

    /** constructor of the behaviour */
    public MessageHandler(FriendTamagotchiAgent agent) {
        super(agent);
        friendTamagotchiAgent = agent;
    }

    /** actual implementation of the behaviour */
    public void action() {
        // Receive the message
        ACLMessage msg = myAgent.receive();
        if (msg == null) {
          block();
        }
        else {
          if (msg.getPerformative() == ACLMessage.INFORM &&
              msg.getContent().equals("Could I come to your place?")) {
              AID sender = msg.getSender();

              /** Prepare and send the INFORM message */
              msg = new ACLMessage(ACLMessage.INFORM);
              msg.setSender(new AID(myAgent.getLocalName(), AID.ISLOCALNAME));
              msg.addReceiver(sender);
              msg.setContent("Please come");
              myAgent.send(msg);
          }
          else if (msg.getPerformative() == ACLMessage.INFORM &&
                   msg.getContent().equals("Good day!")) {
          }
          else if (msg.getPerformative() == ACLMessage.INFORM &&
                   msg.getContent().equals("Playing")) {
          }
          else {
            try {
              Present present = (Present) msg.getContentObject();
              System.out.println("Received present " + present.getPresentType());
            }
            catch (jade.lang.acl.UnreadableException ure) {
              ure.printStackTrace();
            }
          }
        }
      }
    }

    /**
 * to do: description of the behaviour for the javadoc tool.
 */
class Host_the_guest extends OneShotBehaviour {

  /** MyTamagotchiAgent */
  private FriendTamagotchiAgent friendTamagotchiAgent;

  /** User Interface */
  private UserInterface userInterface;

  /** constructor of the behaviour */
  public Host_the_guest(FriendTamagotchiAgent agent, UserInterface ui) {
    super(agent);

    friendTamagotchiAgent = agent;
    userInterface = ui;
  }

  public void action() {
    userInterface.appendMessage("Hosting the guest");
  }
}
