package TamagotchiPackage;

import java.util.*;
import jade.core.*;
import jade.lang.acl.*;
import jade.core.behaviours.*;
import jade.content.onto.*;
import jade.content.lang.*;

import TamagotchiOntology.*;

/**
 * This is the class for implementing the Tamagotchi agent type.
 */
public class Tamagotchi extends Agent {

  /** Information about ontology */
  private Ontology ontology = TamaOntology.getInstance();

  /** User interface */
  private UserInterface ui;

  /** The message to be sent */
  private ACLMessage msg;

  /** Current behaviour */
  private Behaviour currentBehaviour;

  /* The Tamagotchi's level of happiness */
  private double happinessLevel = 0.0;

  /** The Tamagotchi's list of presents */
  Queue<Present> presentList;

  /* The flag showing whether the owner has been informed of a change in the happiness level */
  private boolean owner_informed = false;

  /** The other Tamagotchi */
  private AID friend;

  /** Constructor of the agent */
  public Tamagotchi() {
    super();
  }

  protected void setup() {
    /** Register the ontology used by this agent */
    getContentManager().registerOntology(ontology);

    presentList = new LinkedList();

    presentList.add(new Present ("food"));
    presentList.add(new Present ("chocolate"));
    presentList.add(new Present ("toy"));

    // Adding cyclic behaviours
    addBehaviour(new Mood_checker(this));
    addBehaviour(new Message_handler(this));

    // Creating a new User Interface
    ui = new UserInterface(this);
    ui.show();
  }

  protected void takeDown() {
    // includes clean-up code if needed
  }

  public TamagotchiShell getTamagotchiShell () {
    return (new TamagotchiShell());
  }

  public ACLMessage getMessage() {
    return msg;
  }

  public UserInterface getUserInterface() {
    return ui;
  }

  public void setCurrentBehaviour(Behaviour b) {
    currentBehaviour = b;
  }

  public Behaviour getCurrentBehaviour() {
    return currentBehaviour;
  }

  public void setHappinessLevel(double level) {
    happinessLevel = level;
    owner_informed = false;
  }

  public double getHappinessLevel() {
    return happinessLevel;
  }

  public void addPresent(Present present) {
    presentList.add(present);
  }

  public Present getPresent() {
    return presentList.poll();
  }

  public void ownerIsInformed() {
    owner_informed = true;
  }

  public boolean ownerInformed() {
    return owner_informed;
  }

  public void setFriend(AID fr) {
    friend = fr;
  }

  public AID getFriend() {
    return friend;
  }
}
